This directory enables testing that hab ignores distro version folders defined
in the `ignored_distros` key of the site configuration. It's version is pulled
from the parent directory of the .hab.json file, which is named `pre`.
